@@ -30,9 +30,9 @@ class SingletonForEveryInitArgs(type):
     """Python单例模式(Singleton)的N种实现 - 知乎: https://zhuanlan.zhihu.com/p/37534850
 
     注意！注意！注意！重要的事说三遍！
-    我的单例类不是传统意义上的单例类。
+    这里的单例类不是传统意义上的单例类。
     传统意义的单例类，不管用怎样不同的初始化参数创建对象，永远都只有最初的那个对象类。
-    但是我的单例类，为每种不同的参数创建形式，都构造了一个对象。
+    但是这个单例类，为每种不同的参数创建形式，都构造了一个对象。
     """
     _instances = {}
 
